From 416f7c47be6ede7e6aaf6194e00ba9432097dfd3 Mon Sep 17 00:00:00 2001
From: Ben Pfaff <blp@gnu.org>
Date: Sun, 16 Apr 2006 02:55:39 +0000
Subject: [PATCH] Improve comment.

---
 src/data/variable.h | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/src/data/variable.h b/src/data/variable.h
index 47945241..181d70c8 100644
--- a/src/data/variable.h
+++ b/src/data/variable.h
@@ -40,7 +40,9 @@ enum var_type
 const char *var_type_adj (enum var_type);
 const char *var_type_noun (enum var_type);
 
-/* Maximum variable name lengths. */
+/* Maximum lengths of short and long variable names.
+   Most operations support long variable names,
+   but some file formats are limited to short names. */
 #define SHORT_NAME_LEN 8        /* Short name length. */
 #define LONG_NAME_LEN 64        /* Long name length. */
 
-- 
2.30.2